---

# Remote analysis check

HTML/php website to handle remote analysis shifts

Content `public/`:
- `navbar.html`: Contains the description of the blue navigation bar.
- `index.php`: Start page with shift history.
- `checklist.php`: Page containing the checklist.
- `submit.php`: Submission page showing the summary.

- `style.css`: File defining style for tables, buttons ...

- `recentSQLName.txt`: Only contains name of the latest campaign. This initialises a new sql database table when changed.
- `data/mydb.sqlite`: This file is local on the server and contains the sql database.

## What to update when new campaign starts

Go to the `public` folder:
- `recentSQLName.txt`: Change campaign number (auto-initialises new sql table)
- `navbar.html`: Add link to latest brew table to the navigation bar in the `brew` dropdown menu.
- `checklist.php`: Just search and replace the name of the previous campaign with the name of the current campaign: `KNMx` --> `KNMy`
- `index.php`: Add new campaign to list of campaigns that should be displayed on start page --> `$Campaigns = ["KNMy", ... , "KNM8", "KNM7", "KNM6"];`

## What to update when the KATRIN password changes

- Update salted password in `.htpasswd`
- Update kdb acess link/password in `checklist.php`. Find and edit `XXX` in kdb link: `"http://katrin:XXX@kdb.kaas.kit.edu/kdb-api.fcgi/json?run&system= ..."`. This line pulls the last run number from kdb.

## General stuff

The remote template slides can be changed and updated [here](https://docs.google.com/presentation/d/1Fj3TjNkry1fAC94sEvml2LyvrICDhh_e7i75_7pimqk/edit?usp=sharing)

You can access/bulid the website on `https://kaas.kit.edu:8443/console/` (only works within kit network). To get the password contact Florian Fränkle. 

To build and deploy the page go into the `status` project (same level as bora, katrin ...)
- Build the new page if something is updated. This should happen automatically after every git push. If you need to build it manually, click: `Builds/Builds`-->`remote-shift`-->`Start Build`
- Deploy the page manually: `Application` --> `Deployments` --> `remote-shift` --> `Deploy`. (This could be changed to some automation method in the future)
- Wait some minutes ... Done :)

To develop the page locally on your computer, go to the public folder and run: 
``php -S 127.0.0.1:8000``
then you can access the page in your browser under `http://127.0.0.1:8000`

## What to do if you want to manually change something in the sql database: 

*Only do this if you are confident in what you are doing. Try the commands in your local build first.*

- Login into open shift: `oc login https://kaas.kit.edu:8443` (enter username and password)
- Go into correct project: `oc project status`
- Get a list of the pods: `oc get pods`
- Open a shell for the latest pod: `oc rsh <PodName>`
- Change dir: `cd data`
- Open the sql database manually: `sqlite3 mydb.sqlite`
- Congratulations, you have the power. Now you can use sql commands to manually edit the database. 

<hr>

Author: Leonard Köllenberger
Contact: leonard.koellenberger@kit.edu
